@@ -44,7 +44,7 @@ def tempnam_no_warning(*args):
     """
     return os.tempnam(*args)
 
-class NoDefault:
+class NoDefault(object):
     pass
 
 def sorted(l):
@@ -97,7 +97,8 @@ class TestApp(object):
     disabled = True
 
     def __init__(self, app, namespace=None, relative_to=None,
-                 extra_environ=None):
+                 extra_environ=None, pre_request_hook=None,
+                 post_request_hook=None):
         """
         Wraps a WSGI application in a more convenient interface for
         testing.
@@ -117,6 +118,13 @@ class TestApp(object):
         ``extra_environ`` is a dictionary of values that should go
         into the environment for each request.  These can provide a
         communication channel with the application.
+
+        ``pre_request_hook`` is a function to be called prior to
+        making requests (such as ``post`` or ``get``). This function
+        must take one argument (the instance of the TestApp).
+
+        ``post_request_hook`` is a function, similar to
+        ``pre_request_hook``, to be called after requests are made.
         """
         if isinstance(app, (str, unicode)):
             from paste.deploy import loadapp
@@ -129,6 +137,8 @@ class TestApp(object):
         if extra_environ is None:
             extra_environ = {}
         self.extra_environ = extra_environ
+        self.pre_request_hook = pre_request_hook
+        self.post_request_hook = post_request_hook
         self.reset()
 
     def reset(self):
@@ -198,19 +208,10 @@ class TestApp(object):
         req = TestRequest(url, environ, expect_errors)
         return self.do_request(req, status=status)
 
-    def post(self, url, params='', headers=None, extra_environ=None,
+    def _gen_request(self, method, url, params='', headers=None, extra_environ=None,
              status=None, upload_files=None, expect_errors=False):
         """
-        Do a POST request.  Very like the ``.get()`` method.
-        ``params`` are put in the body of the request.
-
-        ``upload_files`` is for file uploads.  It should be a list of
-        ``[(fieldname, filename, file_content)]``.  You can also use
-        just ``[(fieldname, filename)]`` and the file content will be
-        read from disk.
-
-        Returns a `response object
-        <class-paste.fixture.TestResponse.html>`_
+        Do a generic request.  
         """
         if headers is None:
             headers = {}
@@ -230,13 +231,67 @@ class TestApp(object):
         else:
             environ['QUERY_STRING'] = ''
         environ['CONTENT_LENGTH'] = str(len(params))
-        environ['REQUEST_METHOD'] = 'POST'
+        environ['REQUEST_METHOD'] = method
         environ['wsgi.input'] = StringIO(params)
         self._set_headers(headers, environ)
         environ.update(extra_environ)
         req = TestRequest(url, environ, expect_errors)
         return self.do_request(req, status=status)
 
+    def post(self, url, params='', headers=None, extra_environ=None,
+             status=None, upload_files=None, expect_errors=False):
+        """
+        Do a POST request.  Very like the ``.get()`` method.
+        ``params`` are put in the body of the request.
+
+        ``upload_files`` is for file uploads.  It should be a list of
+        ``[(fieldname, filename, file_content)]``.  You can also use
+        just ``[(fieldname, filename)]`` and the file content will be
+        read from disk.
+
+        Returns a `response object
+        <class-paste.fixture.TestResponse.html>`_
+        """
+        return self._gen_request('POST', url, params=params, headers=headers,
+                                 extra_environ=extra_environ,status=status,
+                                 upload_files=upload_files,
+                                 expect_errors=expect_errors)
+
+    def put(self, url, params='', headers=None, extra_environ=None,
+             status=None, upload_files=None, expect_errors=False):
+        """
+        Do a PUT request.  Very like the ``.get()`` method.
+        ``params`` are put in the body of the request.
+
+        ``upload_files`` is for file uploads.  It should be a list of
+        ``[(fieldname, filename, file_content)]``.  You can also use
+        just ``[(fieldname, filename)]`` and the file content will be
+        read from disk.
+
+        Returns a `response object
+        <class-paste.fixture.TestResponse.html>`_
+        """
+        return self._gen_request('PUT', url, params=params, headers=headers,
+                                 extra_environ=extra_environ,status=status,
+                                 upload_files=upload_files,
+                                 expect_errors=expect_errors)
+
+    def delete(self, url, params='', headers=None, extra_environ=None,
+               status=None, expect_errors=False):
+        """
+        Do a DELETE request.  Very like the ``.get()`` method.
+        ``params`` are put in the body of the request.
+
+        Returns a `response object
+        <class-paste.fixture.TestResponse.html>`_
+        """
+        return self._gen_request('DELETE', url, params=params, headers=headers,
+                                 extra_environ=extra_environ,status=status,
+                                 upload_files=None, expect_errors=expect_errors)
+
+    
+
+
     def _set_headers(self, headers, environ):
         """
         Turn any headers into environ variables
@@ -306,6 +361,8 @@ class TestApp(object):
         ``status``.  Generally ``.get()`` and ``.post()`` are used
         instead.
         """
+        if self.pre_request_hook:
+            self.pre_request_hook(self)
         __tracebackhide__ = True
         if self.cookies:
             c = SimpleCookie()
@@ -349,6 +406,8 @@ class TestApp(object):
             for key, morsel in c.items():
                 self.cookies[key] = morsel.value
                 res.cookies_set[key] = morsel.value
+        if self.post_request_hook:
+            self.post_request_hook(self)
         if self.namespace is None:
             # It's annoying to return the response in doctests, as it'll
             # be printed, so we only return it is we couldn't assign
@@ -359,9 +418,15 @@ class TestApp(object):
         __tracebackhide__ = True
         if status == '*':
             return
+        if isinstance(status, (list, tuple)):
+            if res.status not in status:
+                raise AppError(
+                    "Bad response: %s (not one of %s for %s)\n%s"
+                    % (res.full_status, ', '.join(map(str, status)),
+                       res.request.url, res.body))
+            return
         if status is None:
-            if res.status == 200 or (
-                res.status >= 300 and res.status < 400):
+            if res.status >= 200 and res.status < 400:
                 return
             raise AppError(
                 "Bad response: %s (not 200 OK or 3xx redirect for %s)\n%s"
