@@ -1,7 +1,6 @@
 # (c) 2005 Ben Bangert
 # This module is part of the Python Paste Project and is released under
 # the MIT License: http://www.opensource.org/licenses/mit-license.php
-
 """Registry for handling request-local module globals sanely
 
 Dealing with module globals in a thread-safe way is good if your
@@ -46,7 +45,7 @@ You will then be able to import yourpackage anywhere in your WSGI app or in
 the calling stack below it and be assured that it is using the object you
 registered with Registry.
 
-RegisterManager can be in the WSGI stack multiple times, each time it
+RegistryManager can be in the WSGI stack multiple times, each time it
 appears it registers a new request context.
 
 
@@ -61,8 +60,8 @@ when developing web applications.
 
 Should you be developing a system which may be accessing the proxy object
 thousands of times per request, the performance of the proxy will start to
-become more noticeabe. In that circumstance, the problem can be avoided by
-getting at the actual object via the proxy with the ``_curent_obj`` function:
+become more noticeable. In that circumstance, the problem can be avoided by
+getting at the actual object via the proxy with the ``_current_obj`` function:
 
 .. code-block:: Python
     
@@ -90,14 +89,14 @@ is provided solely in the extremely rare case that it is an issue so that a
 quick way to work around it is documented.
 
 """
-import new
 import sys
-import warnings
 import paste.util.threadinglocal as threadinglocal
 
 __all__ = ['StackedObjectProxy', 'RegistryManager', 'StackedObjectRestorer',
            'restorer']
 
+class NoDefault(object): pass
+
 class StackedObjectProxy(object):
     """Track an object instance internally using a stack
     
@@ -110,7 +109,7 @@ class StackedObjectProxy(object):
     objects can be removed with _pop_object. 
     
     """
-    def __init__(self, default=None, name="Default"):
+    def __init__(self, default=NoDefault, name="Default"):
         """Create a new StackedObjectProxy
         
         If a default is given, its used in every thread if no other object
@@ -119,7 +118,7 @@ class StackedObjectProxy(object):
         """
         self.__dict__['____name__'] = name
         self.__dict__['____local__'] = threadinglocal.local()
-        if default:
+        if default is not NoDefault:
             self.__dict__['____default_object__'] = default
     
     def __getattr__(self, attr):
@@ -129,7 +128,7 @@ class StackedObjectProxy(object):
         setattr(self._current_obj(), attr, value)
     
     def __delattr__(self, name):
-        self._current_obj().__delattr__(name)
+        delattr(self._current_obj(), name)
     
     def __getitem__(self, key):
         return self._current_obj()[key]
@@ -138,33 +137,30 @@ class StackedObjectProxy(object):
         self._current_obj()[key] = value
     
     def __delitem__(self, key):
-        self._current_obj().__delitem__(key)
+        del self._current_obj()[key]
+
+    def __call__(self, *args, **kw):
+        return self._current_obj()(*args, **kw)
     
     def __repr__(self):
         try:
             return repr(self._current_obj())
-        except TypeError:
-            return '<%s.%s object at 0x%08x>' % (__name__,
-                                                   self.__class__.__name__,
-                                                   id(self))
+        except (TypeError, AttributeError):
+            return '<%s.%s object at 0x%x>' % (self.__class__.__module__,
+                                               self.__class__.__name__,
+                                               id(self))
     
     def __iter__(self):
-        """Only works for proxying to a dict"""
-        return iter(self._current_obj().keys())
+        return iter(self._current_obj())
     
     def __len__(self):
         return len(self._current_obj())
     
     def __contains__(self, key):
-        return self._current_obj().has_key(key)
-    
-    def current_obj(self):
-        """
-        Deprecated (Aug 15 2006); moved to _current_obj.
-        """
-        warnings.warn('StackedObjectProxy.current_obj has been moved to '
-                      'StackedObjectProxy._current_obj', DeprecationWarning, 2)
-        return self._current_obj()
+        return key in self._current_obj()
+
+    def __nonzero__(self):
+        return bool(self._current_obj())
 
     def _current_obj(self):
         """Returns the current active object being proxied to
@@ -177,22 +173,14 @@ class StackedObjectProxy(object):
         if objects:
             return objects[-1]
         else:
-            object = self.__dict__.get('____default_object__')
-            if object:
-                return object
+            obj = self.__dict__.get('____default_object__', NoDefault)
+            if obj is not NoDefault:
+                return obj
             else:
                 raise TypeError(
                     'No object (name: %s) has been registered for this '
                     'thread' % self.____name__)
 
-    def push_object(self, obj):
-        """
-        Deprecated (Aug 15 2006); moved to _push_object.
-        """
-        warnings.warn('StackedObjectProxy.push_object has been moved to '
-                      'StackedObjectProxy._push_object', DeprecationWarning, 2)
-        self._push_object(obj)
-
     def _push_object(self, obj):
         """Make ``obj`` the active object for this thread-local.
         
@@ -213,14 +201,6 @@ class StackedObjectProxy(object):
             self.____local__.objects = []
         self.____local__.objects.append(obj)
     
-    def pop_object(self, obj=None):
-        """
-        Deprecated (Aug 15 2006); moved to _pop_object.
-        """
-        warnings.warn('StackedObjectProxy.pop_object has been moved to '
-                      'StackedObjectProxy._pop_object', DeprecationWarning, 2)
-        self._pop_object(obj)
-
     def _pop_object(self, obj=None):
         """Remove a thread-local object.
         
@@ -237,35 +217,47 @@ class StackedObjectProxy(object):
                     'The object popped (%s) is not the same as the object '
                     'expected (%s)' % (popped, obj))
 
-    # The following methods will be swapped for their original versions by
-    # StackedObjectRestorer when EvalException restoration is enabled. The
-    # original functions (e.g. _current_obj) will be available at
-    # _current_obj_orig
+    def _object_stack(self):
+        """Returns all of the objects stacked in this container
 
-    def _current_obj_evalexception(self):
+        (Might return [] if there are none)
+        """
+        try:
+            return self.____local__.objects[:]
+        except AssertionError:
+            return []
+
+    # The following methods will be swapped for their original versions by
+    # StackedObjectRestorer when restoration is enabled. The original
+    # functions (e.g. _current_obj) will be available at _current_obj_orig
+
+    def _current_obj_restoration(self):
         request_id = restorer.in_restoration()
         if request_id:
             return restorer.get_saved_proxied_obj(self, request_id)
         return self._current_obj_orig()
-    _current_obj_evalexception.__doc__ = \
-        ('%s\n(EvalException restoration enabled)' % _current_obj.__doc__)
+    _current_obj_restoration.__doc__ = \
+        ('%s\n(StackedObjectRestorer restoration enabled)' % \
+         _current_obj.__doc__)
 
-    def _push_object_evalexception(self, obj):
+    def _push_object_restoration(self, obj):
         if not restorer.in_restoration():
             self._push_object_orig(obj)
-    _push_object_evalexception.__doc__ = \
-        ('%s\n(EvalException restoration enabled)' % _push_object.__doc__)
+    _push_object_restoration.__doc__ = \
+        ('%s\n(StackedObjectRestorer restoration enabled)' % \
+         _push_object.__doc__)
 
-    def _pop_object_evalexception(self, obj=None):
+    def _pop_object_restoration(self, obj=None):
         if not restorer.in_restoration():
             self._pop_object_orig(obj)
-    _pop_object_evalexception.__doc__ = \
-        ('%s\n(EvalException restoration enabled)' % _pop_object.__doc__)
+    _pop_object_restoration.__doc__ = \
+        ('%s\n(StackedObjectRestorer restoration enabled)' % \
+         _pop_object.__doc__)
 
 class Registry(object):
     """Track objects and stacked object proxies for removal
     
-    The Registry object is instantiated a single time for the rquest no
+    The Registry object is instantiated a single time for the request no
     matter how many times the RegistryManager is used in a WSGI stack. Each
     RegistryManager must call ``prepare`` before continuing the call to
     start a new context for object registering.
@@ -388,21 +380,22 @@ class StackedObjectRestorer(object):
     StackedObjectProxies.
 
     With restoration enabled, those StackedObjectProxies' _current_obj
-    (overwritten by _current_obj_evalexception) method's strategy is modified:
+    (overwritten by _current_obj_restoration) method's strategy is modified:
     it will return its appropriate proxied object from the restorer when
-    EvalException is executing.
+    a restoration context is active in the current thread.
 
-    The StackedObjectProxies' _push/pop_object methods strategy's are also
-    changed: they no-op when EvalException is executing (because the
-    pushing/popping work is all handled by the Registry/restorer).
+    The StackedObjectProxies' _push/pop_object methods strategies are also
+    changed: they no-op when a restoration context is active in the current
+    thread (because the pushing/popping work is all handled by the
+    Registry/restorer).
 
     The request's Registry objects' reglists are restored from the restorer
-    when EvalException begins executing (restoration begins), enabling the
-    Registry methods to work, while their changes are tracked by the restorer.
+    when a restoration context begins, enabling the Registry methods to work
+    while their changes are tracked by the restorer.
 
     The overhead of enabling restoration is negligible (another threadlocal
     access for the changed StackedObjectProxy methods) for normal use outside
-    of EvalException, but worth mentioning when combined with
+    of a restoration context, but worth mentioning when combined with
     StackedObjectProxies normal overhead. Once enabled it does not turn off,
     however:
 
@@ -416,7 +409,7 @@ class StackedObjectRestorer(object):
     def __init__(self):
         # Registries and their saved reglists by request_id
         self.saved_registry_states = {}
-        self.evalcontext_id = threadinglocal.local()
+        self.restoration_context_id = threadinglocal.local()
 
     def save_registry_state(self, environ):
         """Save the state of this request's Registry (if it hasn't already been
@@ -433,7 +426,8 @@ class StackedObjectRestorer(object):
             (registry, registry.reglist[:])
 
         # Tweak the StackedObjectProxies we want to save state for -- change
-        # their methods to act differently when EvalException is executing
+        # their methods to act differently when a restoration context is active
+        # in the current thread
         for reglist in registry.reglist:
             for stacked, obj in reglist.itervalues():
                 self.enable_restoration(stacked)
@@ -441,7 +435,7 @@ class StackedObjectRestorer(object):
     def get_saved_proxied_obj(self, stacked, request_id):
         """Retrieve the saved object proxied by the specified
         StackedObjectProxy for the request identified by request_id"""
-        # All state for the request identifed by request_id
+        # All state for the request identified by request_id
         reglist = self.saved_registry_states[request_id][1]
 
         # The top of the stack was current when the exception occurred
@@ -463,26 +457,26 @@ class StackedObjectRestorer(object):
 
     def enable_restoration(self, stacked):
         """Replace the specified StackedObjectProxy's methods with their
-        respective evalexception versions.
+        respective restoration versions.
 
-        _current_obj_evalexception forces recovery of the saved proxied object
-        during EvalException's EvalContext calls.
+        _current_obj_restoration forces recovery of the saved proxied object
+        when a restoration context is active in the current thread.
 
-        _push/pop_object_evalexception avoid pushing/popping data
-        (pushing/popping is only done at the Registry level) during
-        EvalException's EvalContext calls"""
+        _push/pop_object_restoration avoid pushing/popping data
+        (pushing/popping is only done at the Registry level) when a restoration
+        context is active in the current thread"""
         if '_current_obj_orig' in stacked.__dict__:
             # Restoration already enabled
             return
 
         for func_name in ('_current_obj', '_push_object', '_pop_object'):
             orig_func = getattr(stacked, func_name)
-            evalexception_func = getattr(stacked, func_name + '_evalexception')
+            restoration_func = getattr(stacked, func_name + '_restoration')
             stacked.__dict__[func_name + '_orig'] = orig_func
-            stacked.__dict__[func_name] = evalexception_func
+            stacked.__dict__[func_name] = restoration_func
 
     def get_request_id(self, environ):
-        """Return a uniqe identifier for the current request"""
+        """Return a unique identifier for the current request"""
         from paste.evalexception.middleware import get_debug_count
         return get_debug_count(environ)
 
@@ -494,18 +488,25 @@ class StackedObjectRestorer(object):
             registry, reglist = self.saved_registry_states[request_id]
             registry.reglist = reglist
 
-        self.evalcontext_id.request_id = request_id
+        self.restoration_context_id.request_id = request_id
 
     def restoration_end(self):
         """Register a restoration context as finished, if one exists"""
         try:
-            del self.evalcontext_id.request_id
+            del self.restoration_context_id.request_id
         except AttributeError:
             pass
 
     def in_restoration(self):
         """Determine if a restoration context is active for the current thread.
         Returns the request_id it's active for if so, otherwise False"""
-        return getattr(self.evalcontext_id, 'request_id', False)
+        return getattr(self.restoration_context_id, 'request_id', False)
 
 restorer = StackedObjectRestorer()
+
+
+# Paste Deploy entry point
+def make_registry_manager(app, global_conf):
+    return RegistryManager(app)
+
+make_registry_manager.__doc__ = RegistryManager.__doc__
