@@ -7,8 +7,11 @@ WSGI applications that parse the URL and dispatch to on-disk resources
 import os
 import sys
 import imp
-import pkg_resources
 import mimetypes
+try:
+    import pkg_resources
+except ImportError:
+    pkg_resources = None
 from paste import request
 from paste import fileapp
 from paste.util import import_string
@@ -16,7 +19,7 @@ from paste import httpexceptions
 from httpheaders import ETAG
 from paste.util import converters
 
-class NoDefault:
+class NoDefault(object):
     pass
 
 __all__ = ['URLParser', 'StaticURLParser', 'PkgResourcesParser']
@@ -44,7 +47,7 @@ class URLParser(object):
     These overrides are:
 
     ``urlparser_hook(environ)``
-        This can modified the environment.  Its return value is ignored,
+        This can modify the environment.  Its return value is ignored,
         and it cannot be used to change the response in any way.  You
         *can* use this, for example, to manipulate SCRIPT_NAME/PATH_INFO
         (try to keep them consistent with the original URL -- but
@@ -420,7 +423,7 @@ class StaticURLParser(object):
     """
     Like ``URLParser`` but only serves static files.
 
-    ``max_cache_age``:
+    ``cache_max_age``:
       integer specifies Cache-Control max_age in seconds
     """
     # @@: Should URLParser subclass from this?
@@ -475,11 +478,13 @@ class StaticURLParser(object):
                 start_response('304 Not Modified', headers)
                 return [''] # empty body
         
-        fa = fileapp.FileApp(full)
+        fa = self.make_app(full)
         if self.cache_max_age:
             fa.cache_control(max_age=self.cache_max_age)
         return fa(environ, start_response)
-        
+
+    def make_app(self, filename):
+        return fileapp.FileApp(filename)
 
     def add_slash(self, environ, start_response):
         """
@@ -518,7 +523,7 @@ def make_static(global_conf, document_root, cache_max_age=None):
     Return a WSGI application that serves a directory (configured
     with document_root)
     
-    max_cache_age - integer specifies CACHE_CONTROL max_age in seconds
+    cache_max_age - integer specifies CACHE_CONTROL max_age in seconds
     """
     if cache_max_age is not None:
         cache_max_age = int(cache_max_age)
@@ -528,6 +533,8 @@ def make_static(global_conf, document_root, cache_max_age=None):
 class PkgResourcesParser(StaticURLParser):
 
     def __init__(self, egg_or_spec, resource_name, manager=None, root_resource=None):
+        if pkg_resources is None:
+            raise NotImplementedError("This class requires pkg_resources.")
         if isinstance(egg_or_spec, (str, unicode)):
             self.egg = pkg_resources.get_distribution(egg_or_spec)
         else:
@@ -536,9 +543,9 @@ class PkgResourcesParser(StaticURLParser):
         if manager is None:
             manager = pkg_resources.ResourceManager()
         self.manager = manager
-        self.root_resource = root_resource
-        if root_resource is not None:
-            self.root_resource = os.path.normpath(self.root_resource)
+        if root_resource is None:
+            root_resource = resource_name
+        self.root_resource = os.path.normpath(root_resource)
 
     def __repr__(self):
         return '<%s for %s:%r>' % (
@@ -600,6 +607,8 @@ def make_pkg_resources(global_conf, egg, resource_name=''):
     an egg spec, and a base ``resource_name`` (default empty string)
     which is the path in the egg that this starts at.
     """
+    if pkg_resources is None:
+        raise NotImplementedError("This function requires pkg_resources.")
     return PkgResourcesParser(egg, resource_name)
 
 def make_url_parser(global_conf, directory, base_python_name,
