@@ -19,15 +19,14 @@ import sys
 from urlparse import urlsplit
 import warnings
 
-__all__ = ['get_cookies', 'add_close', 'raw_interactive',
-           'interactive', 'construct_url', 'error_body_response',
-           'error_response', 'send_file', 'has_header', 'header_value',
-           'path_info_split', 'path_info_pop', 'capture_output',
-           'catch_errors', 'dump_environ', 'intercept_output',
-           'chained_app_iters']
+__all__ = ['add_close', 'add_start_close', 'capture_output', 'catch_errors',
+           'catch_errors_app', 'chained_app_iters', 'construct_url',
+           'dump_environ', 'encode_unicode_app_iter', 'error_body_response',
+           'error_response', 'get_cookies', 'has_header', 'header_value',
+           'interactive', 'intercept_output', 'path_info_pop',
+           'path_info_split', 'raw_interactive', 'send_file']
 
-
-class add_close:
+class add_close(object):
     """
     An an iterable that iterates over app_iter, then calls
     close_func.
@@ -56,10 +55,10 @@ class add_close:
             # We can't raise an error or anything at this stage
             print >> sys.stderr, (
                 "Error: app_iter.close() was not called when finishing "
-                "WSGI request.  finalization function %s not called"
+                "WSGI request. finalization function %s not called"
                 % self.close_func)
 
-class add_start_close:
+class add_start_close(object):
     """
     An an iterable that iterates over app_iter, calls start_func
     before the first item is returned, then calls close_func at the
@@ -95,10 +94,10 @@ class add_start_close:
             # We can't raise an error or anything at this stage
             print >> sys.stderr, (
                 "Error: app_iter.close() was not called when finishing "
-                "WSGI request.  finalization function %s not called"
+                "WSGI request. finalization function %s not called"
                 % self.close_func)
 
-class chained_app_iters:
+class chained_app_iters(object):
 
     """
     Chains several app_iters together, also delegating .close() to each
@@ -140,10 +139,10 @@ class chained_app_iters:
             # We can't raise an error or anything at this stage
             print >> sys.stderr, (
                 "Error: app_iter.close() was not called when finishing "
-                "WSGI request.  finalization function %s not called"
+                "WSGI request. finalization function %s not called"
                 % self.close_func)
 
-class encode_unicode_app_iter:
+class encode_unicode_app_iter(object):
     """
     Encodes an app_iterable's unicode responses as strings
     """
